==> fillets-ng-data_0.7.1.orig.tar.gz: fillets-ng-data-0.7.1/script/ufo/dialogs_fr.lua <==

dialogId("ufo-v-znicilo", "font_big", "We must be getting near the end of our mission. This is surely the UFO that destroyed our house.")
dialogStr("Nous devons être proches de la fin de notre mission. C'est probablement l'OVNI qui a détruit notre maison.")


dialogId("ufo-m-osmy", "font_small", "Are you sure? This is only the eighth level.")
dialogStr("Tu es sûr ? C'est seulement le niveau huit.")


dialogId("ufo-m-valce", "font_small", "These steel cylinders are pretty obnoxious.")
dialogStr("Ces cylindres en acier sont odieux.")


dialogId("ufo-m-moc", "font_small", "There is just too much steel here.")
dialogStr("Il y a seulement trop d'acier ici.")


dialogId("ufo-v-hur", "font_big", "It could be worse. I for one can imagine myself a room where there is nothing but steel.")
dialogStr("Ca pourrait être pire. Pour ma part je peux très bien imaginer une pièce où il n'y aurait que de l'acier.")


dialogId("ufo-m-ne", "font_small", "My goodness! What should I do in such a level?")
dialogStr("Mon dieu ? Que pourrais-je faire dans un tel niveau ?")


dialogId("ufo-v-vpredu", "font_big", "You would let me go in front, for a change.")
dialogStr("Tu devras me laisser passer devant pour une fois.")


dialogId("ufo-m-zvlastni", "font_small", "It`s interesting that this tangled steel forestalls our entry into that UFO more effectively than any security system.")
dialogStr("C'est intéressant comme cet enchevêtrement d'acier nous interdit l'accès de l'OVNI plus efficacement qu'un système de sécurité.")


dialogId("ufo-v-rikam", "font_big", "I keep telling you that our life is controlled by some higher, strange consciousness.")
dialogStr("Je continue à dire que notre vie est dirigée par quelque conscience supérieure.")


dialogId("ufo-m-vidim", "font_small", "I can see that, too. But I am not that sure it`s higher.")
dialogStr("Je vois. Mais je ne suis pas sûr qu'elle soit supérieure.")


dialogId("ufo-v-dovnitr", "font_big", "What can we find inside, once we manage to get there?")
dialogStr("Qu'est ce que nous trouverons à l'intérieur, quand nous y serons ?")


dialogId("ufo-m-tajemstvi", "font_small", "Secrets of another civilization, new technologies, new sources of energy...")
dialogStr("Les secrets d'une autre civilisation, de nouvelles technologies, de nouvelles sources d'énergie...")


dialogId("ufo-v-zjistit0", "font_big", "Most importantly, we should try to find out why they came at all.")
dialogStr("Le plus important, essayons de découvrir pourquoi ils sont venus.")


dialogId("ufo-v-zjistit1", "font_big", "You know, most of all I wonder why they crashed just here.")
dialogStr("Tu sais, je me demande juste pourquoi ils se sont écrasés ici.")


dialogId("ufo-m-tady", "font_small", "Didn`t you see it? Everything happens just here.")
dialogStr("Tu n'as pas remarqué ? Simplement Tout se passe ici.")


dialogId("ufo-m-nevim", "font_small", "I don`t know why the UFOs keep crashing at our house, either.")
dialogStr("Je ne sais toujours pas pourquoi l'OVNI s'est écrasé sur notre maison.")

==> fillets-ng-data_0.8.0.orig.tar.gz: fillets-ng-data-0.8.0/script/ufo/dialogs_fr.lua <==

dialogId("ufo-v-znicilo", "font_big", "We must be getting near the end of our mission. This is surely the UFO that destroyed our house.")
dialogStr("Nous devons être proches de la fin de notre mission. C'est probablement l'OVNI qui a détruit notre maison.")


dialogId("ufo-m-osmy", "font_small", "Are you sure? This is only the eighth level.")
dialogStr("Tu es sûr ? C'est seulement le niveau huit.")


dialogId("ufo-m-valce", "font_small", "These steel cylinders are pretty obnoxious.")
dialogStr("Ces cylindres en acier sont assez désagréables.")


dialogId("ufo-m-moc", "font_small", "There is just too much steel here.")
dialogStr("Il y a vraiment trop d'acier ici.")


dialogId("ufo-v-hur", "font_big", "It could be worse. I for one can imagine myself a room where there is nothing but steel.")
dialogStr("Ça pourrait être pire. Pour ma part je peux très bien imaginer une pièce où il n'y aurait que de l'acier.")


dialogId("ufo-m-ne", "font_small", "My goodness! What should I do in such a level?")
dialogStr("Mon dieu ? Que pourrais-je faire dans un tel niveau ?")


dialogId("ufo-v-vpredu", "font_big", "You would let me go in front, for a change.")
dialogStr("Tu devrais me laisser passer devant pour une fois.")


dialogId("ufo-m-zvlastni", "font_small", "It’s interesting that this tangled steel forestalls our entry into that UFO more effectively than any security system.")
dialogStr("C'est intéressant comme cet enchevêtrement d'acier nous interdit l'accès de l'OVNI plus efficacement qu'un système de sécurité.")


dialogId("ufo-v-rikam", "font_big", "I keep telling you that our life is controlled by some higher, strange consciousness.")
dialogStr("Je continue à dire que notre vie est dirigée par quelque conscience supérieure.")


dialogId("ufo-m-vidim", "font_small", "I can see that, too. But I am not that sure it’s higher.")
dialogStr("Je vois. Mais je ne suis pas sûr qu'elle soit si supérieure.")


dialogId("ufo-v-dovnitr", "font_big", "What can we find inside, once we manage to get there?")
dialogStr("Qu'est ce que nous trouverons à l'intérieur, quand nous y serons ?")


dialogId("ufo-m-tajemstvi", "font_small", "Secrets of another civilization, new technologies, new sources of energy...")
dialogStr("Les secrets d'une autre civilisation, de nouvelles technologies, de nouvelles sources d'énergie...")


dialogId("ufo-v-zjistit0", "font_big", "Most importantly, we should try to find out why they came at all.")
dialogStr("Le plus important, essayons de découvrir pourquoi ils sont venus.")


dialogId("ufo-v-zjistit1", "font_big", "You know, most of all I wonder why they crashed just here.")
dialogStr("Tu sais, je me demande par dessus tout pourquoi ils se sont écrasés ici.")


dialogId("ufo-m-tady", "font_small", "Didn’t you see it? Everything happens just here.")
dialogStr("Tu n'as pas remarqué ? Tout se passe à cet endroit.")


dialogId("ufo-m-nevim", "font_small", "I don’t know why the UFOs keep crashing at our house, either.")
dialogStr("Je ne sais pas non plus pourquoi les OVNIs s'écrasent toujours sur notre maison.")
